@@ -3,4 +3,4 @@ Mixture of factor analyzers.
 
 """
 
-__version__ = "0.0.1"
+from .mofa import Mofa
